# Copyright Spack Project Developers. See COPYRIGHT file for details.
#
# SPDX-License-Identifier: (Apache-2.0 OR MIT)

from spack.package import *


class PyHepstats(PythonPackage):
    """hepstats is a library for statistical inference aiming
    to cover the needs in High Energy Physics.
    It is part of the Scikit-HEP project.
    """

    homepage = "https://github.com/scikit-hep/hepstats"
    pypi = "hepstats/hepstats-0.8.1.tar.gz"
    maintainers("jonas-eschle")

    license("BSD-3-Clause", checked_by="jonas-eschle")

    tags = ["likelihood", "statistics", "inference", "fitting", "hep"]

    version("0.9.2", sha256="cf929871d45e338492eef585faaaa23eff93b200b4787d6b6181dc81f2607be7")
    version("0.8.1", sha256="ebb890496d7aebbf1d717de15d073be31d6775065308a4e0f263ed4051992b3f")

    depends_on("python@3.9:", type=("build", "run"), when="@0.8:")
    # Build system changed from setuptools to hatch with v0.9.0
    depends_on("py-setuptools@42:", type="build", when="@:0.8.1")
    depends_on("py-setuptools-scm@3.4:+toml", type="build", when="@:0.8.1")
    depends_on("py-hatchling", type="build", when="@0.9.0:")
    depends_on("py-hatch-vcs", type="build", when="@0.9.0:")

    variant("zfit", default=False, description="Allows to use improved tools from zfit.")

    with default_args(type=("build", "run")):
        depends_on("py-pandas")
        depends_on("py-numpy")
        depends_on("py-asdf")
        depends_on("py-scipy")
        depends_on("py-tqdm")
        depends_on("py-uhi")

        with when("+zfit"):
            depends_on("py-zfit@0.20:", when="@0.8:")
